// Used to ensure that Entities used in L10N strings are correct
function calp_convert_entities( o ) {
	var c, v;

	c = function( s ) {
		if( /&[^;]+;/.test( s ) ) {
			var e = document.createElement( 'div' );
			e.innerHTML = s;
			return ! e.firstChild ? s : e.firstChild.nodeValue;
		}
		return s;
	}

	if( typeof o === 'string' ) {
		return c( o );
	} else if( typeof o === 'object' ) {
		for( v in o ) {
			if( typeof o[v] === 'string' ) {
				o[v] = c( o[v] );
			}
		}
	}
	return o;
}

jQuery( document ).ready( function( $ ) {

	// =====================================
	// = Calendar CSS selector replacement =
	// =====================================

	if( calp_calendar.selector != undefined && calp_calendar.selector != '' &&
	    $( calp_calendar.selector ).length == 1 )
	{
		// Try to find an <h#> element containing the title
		var $title = $( ":header:contains(" + calp_calendar.title + "):first" );
		// If none found, create one
		if( ! $title.length ) {
			$title = $( '<h1 class="page-title"></h1>' );
			$title.text( calp_calendar.title ); // Do it this way to automatically generate HTML entities
		}

		var $calendar = $( '#calp-container' )
			.detach()
			.before( $title );

		$( calp_calendar.selector )
			.empty()
			.append( $calendar )
			.hide()
			.css( 'visibility', 'visible' )
			.fadeIn( 'fast' );
	}

	// =================================
	// = General script initialization =
	// =================================

	// Variable storing currently displayed view
	var current_hash = '';
	// An array caching the IDs of all event posts in the currently active view
	var post_ids;

	// Check whether appropriate classes have been added to <body> (some themes
	// don't respect the WP body_class() function). If not, add them, or our app
	// won't function properly.
	var classes = $('body').attr( 'class' );
	if( classes == undefined ) classes = '';
	if( classes.match( /\s?\bcalp-[\w-]+\b/ ) == null ) {
		// Add action body class(es)
		classes += ' ' + calp_calendar.body_class;
		$('body').attr( 'class', classes );
	}

	/**
	 * Function used to update view if user has clicked back/forward in the
	 * browser.
	 */
	function check_hash() {
		var live_hash = document.location.hash;
		var default_hash = calp_convert_entities( calp_calendar.default_hash );
		// If current_hash doesn't match live hash, and the document's live hash
		// isn't empty, or if it is, the current_hash isn't equivalent to empty
		// (i.e., default hash), the page needs to be updated.
		if(  (current_hash != live_hash &&
		    ( live_hash != '' || current_hash != default_hash ) )
            || live_hash == '' && current_hash == '' ) {
			// If hash is empty, resort to original requested action
			var hash = live_hash;
			if( ! hash )
				hash = default_hash;
			load_view( hash );
		}
	}

	// Monitor browser navigation between different URL #hash values
	setInterval( check_hash, 300 );

	/**
	 * Load a calendar view represented by the given hash value.
	 */
	function load_view( hash ) {

		// Reveal loader behind view
		$('#calp-calendar-view-loading').fadeIn( 'fast' );
		$('#calp-calendar-view').fadeTo( 'fast', 0.3,
			// After loader is visible, fetch new content
			function() {
                var cat_ids = apply_filters();
				var query = hash.substring( 1 ) ;//+ '&calp_cat_ids=1,2,3,4';
                if ( cat_ids )
                    query += '&calp_cat_ids='+cat_ids;
                
				// Fetch AJAX result
				$.post( calp_calendar.ajaxurl, query, function( data )
					{
						// Replace action body class with new one
						var classes = $('body').attr( 'class' );
						classes = classes.replace( /\s?\bcalp-[\w-]+\b/g, '' );
						classes += ' ' + data.body_class;
						$('body').attr( 'class', classes );

						// Animate vertical height of container between HTML replacement
						var $container = $('#calp-calendar-view-container');
						$container.height( $container.height() );
						var new_height =
							$('#calp-calendar-view')
								.html( data.html );
								//.height();
						/*$container.animate( { height: new_height }, { complete: function() {
							// Restore height to automatic upon animation completion for
							// proper page layout.
							$container.height( 'auto' );
						} } ); */
                        
                        $container.height( 'auto' );

						// Do any general view initialization after loading
						initialize_view();
					},
					'json'
				);
			} );

		// Update stored hash
		current_hash = hash;
	}

    $('a.calp-load-view').die('click');
	// Register navigation click handlers
	$('a.calp-load-view').live( 'click', function() {
		// Load requested view
		load_view( $(this).attr( 'href' ) );
	} );

	// *** Month/week views ***

	/**
	 * Callback for mouseenter event on .calp-event element
	 */
	function show_popup() {
		var $popup = $(this).prev();

		// If not already done, position popup so that it does not exceed
		// right/left bounds of container.
		if( ! $popup.data( 'calp_offset' ) ) {
			// Keep popup hidden but positionable
			$popup.css( 'visibility', 'hidden' ).show();

			var $container = $('#calp-calendar-view-container');
			var popup_width = $popup.width();
			var popup_offset = $popup.offset();
			var container_offset = $container.offset();
			var container_x2 = container_offset.left + $container.width();
			// Respect leflt-side bounds
            if( $( '.calp-event-summary', $popup ).offset().left - 500 < container_offset.left )
			//if( $( '.calp-event-summary', $popup ).offset().left < container_offset.left )
				$popup.addClass( 'calp-shifted-right' );
            // Respect right-side bounds
			//if( popup_offset.left + popup_width > container_x2 )
				//$popup.offset( { left: container_x2 - popup_width, top: popup_offset.top } );
            if( popup_offset.left + popup_width - 50 > container_x2 )
				$popup.offset( { left:  popup_offset.left - popup_width - 112, top: popup_offset.top } );
			// Restore popup to 'display: none'
			$popup.hide().css( 'visibility', 'visible' );
			// Flag the object so we don't calculate twice.
			$popup.data( 'calp_offset', true );
		}
	}
    
	function hide_popup() {
		$(this)
			.fadeOut( 100, function() { $(this).parent().css( { zIndex: 'auto' } ); } )
			.data( 'calp_mouseinside', false );
	}

	// Register popup click handlers for month/week views
	$('.calp-month-view .calp-event, .calp-week-view .calp-event, .calp-week-view .calp-event-container ')
        .live ('click', function(e) {
            // Get click coordinates
            var x = e.pageX ;//- this.offsetLeft;
            var y = e.pageY ;//- this.offsetTop;
            
            // Get popup
            if ( $(this).hasClass('calp-event-container') 
                || $(this).hasClass('calp-item')
            ) {
                var $popup = $(this).children('.calp-event-popup');
            } else {
                var $popup = $(this).prev();
            }
			// Keep popup hidden but positionable
			$popup.css( 'visibility', 'hidden' ).show();
			var $container = $('#calp-calendar-view-container');
            var $tooltip = $('.calp-left-arrow');
			var popup_width = $popup.width();
			var popup_height = $popup.height();
            var arrow_top = Math.abs( popup_height / 2 - $tooltip.height() );
            // Respect leflt-side bounds
			if( x - popup_width < $container.offset().left ) {
				$popup.addClass( 'calp-shifted-right' );
                $( '.calp-left-arrow', $popup ).css('top', arrow_top );
                $popup.offset( { left:  x , top: y - popup_height / 2 } );
            } else {
                $popup.offset( { left:  x - popup_width,  top: y - popup_height / 2  } );
                $( '.calp-right-arrow', $popup ).css('top', arrow_top );
            }
			// Restore popup to 'display: none'
            
            $popup.show().css( 'visibility', 'visible' );
            
			// Flag the object so we don't calculate twice.
			$popup.data( 'calp_offset', true );
    } );
    
    // hide all popups
    $('body').click(function (e) {
        if ($(e.target).closest('.calp-event-popup').length == 0) {
            $('.calp-event-popup:visible').each( hide_popup );
        }
        
        $('.showed-popup').removeClass('showed-popup');
        
        if ( $(e.target).closest('#calp-calendar-picker').length == 0 
            && $('#calp-calendar-picker').css('display') != 'none'
            ) {
                $('#calp-calendar-picker').fadeOut( 'fast' );
                $('.calp-dropdown').parent().removeClass('calp-calander-showed');
                
                 load_view( document.location.hash );
        }
        
        if ( $(e.target).closest('#calp-export-tooltip').length == 0 
            && $('#calp-export-tooltip').css('display') != 'none')
                $('#calp-export-tooltip').fadeOut( 'fast' );
    });
    
    // hide popup if escape pressed
    $(document).on('keydown.closeEsc', function(e){
        if(e == null) {
            k = event.keyCode;
        } else {
            k = e.which;
        }
        if(k == 27) {
            $('.calp-event-popup:visible').each( hide_popup );
            
            $('.showed-popup').removeClass('showed-popup');
            
            if( $('#calp-calendar-picker').css('display') != 'none' ) {
                $('#calp-calendar-picker').fadeOut( 'fast' );
                $('.calp-dropdown').parent().removeClass('calp-calander-showed');
                 load_view( document.location.hash );
            }
            
            if( $('#calp-export-tooltip').css('display') != 'none' )
                $('#calp-export-tooltip').fadeOut( 'fast' );
        }
    });
    
    // Close popup button click
    $('.calp-close-popup').live('click', function () {
        $('.calp-event-popup:visible').each( hide_popup );
    });
    
    // Hide popup on read more click
    jQuery('.calp-popup-read-more').die('click').live('click', function() {
        $('.calp-event-popup:visible').each( hide_popup );
    });
    
	// ================================
	// = Week view hover-raise effect =
	// ================================
	$( '.calp-week-view .calp-week a.calp-event-container' )
		.live( 'mouseenter',
			function() {
				$(this).delay( 500 ).queue( function() { $(this).css( 'z-index', 5 ) } );
			} )
		.live( 'mouseleave',
			function() {
				$(this).clearQueue().css( 'z-index', 'auto' );
			} );

	/**
	 * Trims date boxes for which there are too many listed events.
	 */
	function truncate_month_view()
	{
		if( $( '.calp-month-view' ).length )
		{
			// First undo any previous truncation
			$( '.calp-day .calp-obscured' ).removeClass( 'calp-obscured' );
			$( '.calp-day .calp-scroll-up, .calp-day .calp-scroll-down' ).remove();

			// Now set up truncation on any days with max visible events.
			$( '.calp-month-view .calp-day' ).each( function()
			{
				var max_visible = 8;
				var $events = $( '.calp-event-container:visible', this );

				if( $events.length > max_visible )
				{
					/**
					 * Scroll up by one event.
					 */
					function scroll_up( $el ) {
						if( ! $el.hasClass( 'calp-disabled' ) ) {
							var $first_visible =
								$el.siblings( '.calp-event-container:not(.calp-obscured)' )
									.last().addClass( 'calp-obscured' ).end()
									.first().prev( '.calp-event-container' ).removeClass( 'calp-obscured' );
							if( $first_visible.prev( '.calp-event-container' ).length == 0 )
								$el.addClass( 'calp-disabled' );
							$el.parent().find( '.calp-scroll-down' ).removeClass( 'calp-disabled' );
						}
					}

					/**
					 * Scroll down by one event.
					 */
					function scroll_down( $el ) {
						if( ! $el.hasClass( 'calp-disabled' ) ) {
							var $last_visible =
								$el.siblings( '.calp-event-container:not(.calp-obscured)' )
									.first().addClass( 'calp-obscured' ).end()
									.last().next( '.calp-event-container' ).removeClass( 'calp-obscured' );
							if( $last_visible.next( '.calp-event-container' ).length == 0 )
								$el.addClass( 'calp-disabled' );
							$el.parent().find( '.calp-scroll-up' ).removeClass( 'calp-disabled' );
						}
					}

					/**
					 * Mouse button held down on a scroll button.
					 */
					function scroll_hold( $el, func ) {
						$el.delay( 100 ).queue( function( next ) {
							func( $el );
							scroll_hold( $el, func );
							next();
						} );
					}
					/**
					 * Mouse button let go of a scroll button.
					 */
					function scroll_cancel() {
						$( this ).clearQueue();
					}

					/**
					 * Register mousedown action. Trigger once right away, then again
					 * after 600 ms delay, then again every 100 ms while held down.
					 */
					function register_mousedown( $button, func ) {
						$button.mousedown( function( e ) {
							if( e.button == 0 ) {
								func( $( this ) ); // Scroll once
								$( this )
									.delay( 600 )
									.queue( function( next ) {
										func( $( this ) ); // Scroll again after 600 ms
										scroll_hold( $( this ), func ); // Scroll repeatedly
										next();
									} );
							}
						} );
					}

					// Scroll up button, and register mousedown
					$scroll_up = $( '<a href="#" class="calp-scroll-up calp-disabled"></a>' )
					register_mousedown( $scroll_up, scroll_up );

					// Scroll down button, and register mousedown
					$scroll_down = $( '<a href="#" class="calp-scroll-down"></a>' );
					register_mousedown( $scroll_down, scroll_down );

					// Register scroll cancel events
					$scroll_up.add( $scroll_down )
						.mouseup( function ( e ) {
							if( e.button == 0 )
								$( this ).each( scroll_cancel );
						} )
						.mouseout( scroll_cancel )
						.click( function() { return false } );

					// Attach scroll buttons to date DIV
					$events
						.first().before( $scroll_up ).end()
						.last().after( $scroll_down ).end()
						.filter( ':gt(' + max_visible + ')' ).addClass( 'calp-obscured' );
				}
			} );
		}
	}

	// *** Agenda view ***

	/**
	 * Callbacks for event expansion, collapse.
	 */
	function expand_event() {
		$( this )	// ...-click block
			.hide()
			.parent() // event block
				.addClass( 'calp-expanded' )
				.end()
			.prev()	// summary block
				.show()
				.find( '.calp-event-description' ) // description block
					.hide()
					.slideDown( 'fast' );
	}
	function collapse_event() {
		$(this) // inner ...-click block
			.next() // description block
			.slideUp( 'fast', function() {
				$(this).parent() // summary block
					.parent() // event block
						.removeClass( 'calp-expanded' )
						.end()
					.hide() // summary block again
						.next() // original ...-click block
						.show();
				}
			);
	}

	// Register click handlers for event title
	$('.calp-agenda-view .calp-event > .calp-event-click')
		.live( 'click', expand_event );
	$('.calp-agenda-view .calp-event-summary > .calp-event-click')
		.live( 'click', collapse_event );

	// Register click handlers for expand/collapse all buttons
	$('.calp-action-agenda #calp-expand-all').live( 'click', function() {
		$('.calp-event > .calp-event-click:visible').click();
	} );
	$('.calp-action-agenda #calp-collapse-all').live( 'click', function() {
		$('.calp-event-summary > .calp-event-click:visible').click();
	} );

	// *** All views ***

	// ========================
	// = Category/tag filters =
	// ========================

	element_selector(
			'.calp-category-filter-selector li',
			'calp-selected',
			'calp-categories',
			'#calp-selected-categories' );
	element_selector(
			'.calp-tag-filter-selector li',
			'calp-selected',
			'calp-tags',
			'#calp-selected-tags' );

	// ==================================
	// = Category/tag filtering actions =
	// ==================================

	/**
	 * Checks if the date element in Agenda view contains visible events
	 */
	function has_visible_events( $el ) {
		var ret = false;
		$el.find( 'ol.calp-date-events li.calp-event' ).each( function() {
			if( $( this ).css( 'display' ) != 'none' ) ret = true;
		});
		return ret;
	}

	/**
	 * Applies the active category/tag filters to the current view.
	 * (Shows/hides events as necessary.)
	 */
	function apply_filters()
	{
        var query = {
			'action': 'calp_term_filter',
			'calp_post_ids': post_ids,
			'calp_term_ids': selected_ids
		};
        
		// Submit the selected term IDs via AJAX and filter the visible list of
		// post IDs. Only include filter selectors that have a selection.
		var selected_ids = new Array();
        var selected_cats = '';
        var cat_item = 0;
        $('.calp-category-filter-selector ul li.calp-selected').each(function() {
            cat_item = $(this).val();
            if ( cat_item > 0 ) {  
                selected_ids.push( cat_item );
            }
        })
        
        if ( selected_ids.length ) {
             selected_cats = '&calp_cat_ids=' + selected_ids.join();
        }
        
		selected_tags =
			$('.calp-filters-container .calp-dropdown.calp-selected + #calp-selected-tags').val();
		if( selected_tags ) {
			selected_ids.push( selected_tags );
			selected_tags = '&calp_tag_ids=' + selected_tags;
		} else {
			selected_tags = '';
		}

		selected_ids = selected_ids.join();

		// Modify export URL
		var export_url = calp_convert_entities( calp_calendar.export_url );
		if( selected_ids.length ) {
			export_url += selected_cats + selected_tags;
		}
        
		var query = {
			'action': 'calp_term_filter',
			'calp_post_ids': post_ids,
			'calp_term_ids': selected_ids
		};

        return selected_ids;
	}

	/**
	 * Updates the filter dropdowns and clear button based on whether filters
	 * are selected.
	 */
	function update_filter_selectors() {
		// Highlight this dropdown as "selected" if and only if any of its terms
		// have been selected.
		/*$( '.calp-category-filter-selector ul' ).each( function() {
			if( $( 'li.calp-selected', this ).length ) {
				$( '.calp-dropdown', this ).addClass( 'calp-selected' );
			} else {
				$( '.calp-dropdown', this ).removeClass( 'calp-selected' );
			}
		} );

		if( $('.calp-filters-container .calp-selected').length )
			$('.calp-clear-filters').fadeIn( 'fast' );
		else
			$('.calp-clear-filters').fadeOut( 'fast' );
*/
		
	}
    
    // display filter block
    $('.calp-dropdown').live('click', function() {
        if( $('#calp-calendar-picker').css('display') == 'none' ) {
            $('#calp-calendar-picker').fadeIn( 'fast' );
            $('.calp-dropdown').parent().addClass('calp-calander-showed');
        } else {
			$('#calp-calendar-picker').fadeOut( 'fast' );
            $('.calp-dropdown').parent().removeClass('calp-calander-showed');
            
            load_view( document.location.hash );
        }
    } ); 
    
    // show / hide categgories in filted
    $('#show-hide-categories').live('click', function() {
        
        if ( $('#show-hide-categories').html() == 'Hide All Calanders' ) {
            $('.calp-filter-selector-container li').removeClass( 'calp-selected' );
            $('#show-hide-categories').html('Show All Calanders')
        } else {
            $('.calp-filter-selector-container li').addClass( 'calp-selected' );
            $('#show-hide-categories').html('Hide All Calanders')
        }
        
    } ); 
    
    // show / hide export popup
    
    $('.calp-export-add').live('click', function() {
        if( $('#calp-export-tooltip').css('display') == 'none' ) {
            $('#calp-export-tooltip').fadeIn( 'fast' );
        } else {
			$('#calp-export-tooltip').fadeOut( 'fast' );
        }
    } );

	/**
	 * function initialize_view
	 *
	 * General initialization function to execute whenever any view is loaded
	 * (this is also called at the end of load_view()).
	 */
	function initialize_view()
	{
		// Cache the current list of post IDs
		post_ids = new Array();
		$( '.calp-post-id' ).each( function() {
			post_ids.push( this.value );
		} );
		post_ids = post_ids.join();	// Store IDs as comma-separated values

		// Make week view table scrollable
		$( 'table.calp-week-view-original' ).tableScroll( { height: 400, containerClass: 'calp-week-view' } );

		// ===========================
		// = Pop up the active event =
		// ===========================
		if( $( '.calp-active-event:first' ).length ) {
			// Pop up any active event in month/week view views
			$( '.calp-month-view .calp-active-event:first, .calp-week-view .calp-active-event:first' )
				.each( function() {
				$(this)
					.each( show_popup )
					.prev() // .calp-popup
						.data( 'calp_mouseinside', true ); // To keep pop-up from vanishing
			} );
			// Expand any active event in agenda view
			$( '.calp-agenda-view .calp-active-event:first > .calp-event-click' ).each( expand_event );
			// Bring the active event into focus
			$.scrollTo( '.calp-active-event:first', 1000,
				{
					offset: {
						left: 0,
						top: -window.innerHeight / 2 + 100
					}
				}
			);
		}
		else if( $( '.calp-week-view' ).length ) {
			// If no active event, then in week view, scroll down to 6am.
			$( '.calp-week-view .tablescroll_wrapper' ).scrollTo( '.calp-hour-marker:eq(6)' );
		}
        
        // Hide loader
        $('#calp-calendar-view-loading').fadeOut( 'fast' );
        $('#calp-calendar-view').fadeTo( 'fast', 1.0 );
	}

	// If there are preselected tag/cat IDs, update the filter UI
	if( $('#calp-selected-categories').val() != '' ||
			$('#calp-selected-tags').val() != '' )
		update_filter_selectors();
	initialize_view();
    
} );

    /**
     * Navigation previous link
     */
    function navigation_prev(href)
    {
        window.location.href = href;
    }
    
     /**
     * Navigation next link
     */
    function navigation_next(href)
    {
        window.location.href = href;
    }
    
    /**
     * Go to event on agenda page
     */
    function go_to_event(event_id)
    {
        var query = {
			'action': 'calp_agenda_item',
			'calp_item_id':  event_id
		};

        // Delay loading animation so that it doesn't appear if the AJAX turnover
		// is quick enough
        jQuery('#calp-calendar-view-loading').fadeIn( 'fast' );
		jQuery('#calp-calendar-view').fadeTo( 'fast', 0.3);
		
        jQuery.post( calp_calendar.ajaxurl, query, function( data ) {
            if ( data.html ) {
                jQuery('#calp-event-single').html( data.html );
            } else {
                jQuery('#calp-event-single').html( '<div class="calp-no-events"><div style="padding-top: 230px">No Events</div></div>' );
            }
            
            // Hide loader
            jQuery('#calp-calendar-view-loading').fadeOut( 'fast' );
            jQuery('#calp-calendar-view').fadeTo( 'fast', 1.0 );
            
        }, 'json');
  }
  
    /**
   * Show Item popup
   */
    function show_item_popup(event_id, x, y)
    {
        var query = {
			'action': 'calp_popup',
			'calp_item_id':  event_id
		};
		
        jQuery.post( calp_calendar.ajaxurl, query, function( data ) {
            if ( data.html ) {
                var container = jQuery('#calp-calendar-view-container');
                var popup = jQuery(data.html);
                jQuery('body').append( popup );
                var tooltip = jQuery('.calp-left-arrow');
                var popup_width = 350;
                var popup_height = popup.height();
                var arrow_top = Math.abs( popup_height / 2 - tooltip.height() );
                jQuery('body .calp-event-popup').remove();
                var popup = jQuery(data.html);
                if( x - popup_width < container.offset().left ) {
                    popup.addClass( 'calp-shifted-right' );
                    jQuery( '.calp-left-arrow', popup ).css('left','1px').css('top', arrow_top );
                    //popup.offset( { left:  10 , top: 20 } );
                    popup.css('left', x+'px').css('top', y - popup_height / 2 + 'px' );
                } else {
                    popup.css('left',   x - popup_width +'px').css('top', y - popup_height / 2 + 'px' );
                    //popup.offset( { left:  x - popup_width,  top: y - popup_height / 2  } );
                    jQuery( '.calp-right-arrow', popup ).css('left','329px').css('top', arrow_top );
                }
                
                popup.css('position', 'absolute').css('z-index', '10002').css('visibility', 'visible');
                popup.css('visibility', 'visible');
                jQuery('body').append( popup ).show();
            }
        }, 'json');
  }
  
    var CALPFull = {
      offClass            : "calp-fullscreen-off",
      onClass             : "calp-fullscreen-on",
      mainFrame           : "calp-container",
      cover               : "calp-fullscreen-cover",
      fullscreenClass     : "calp-fullscreen",
      fullscreenBigClass  : "calp-fullscreen-extra",
      fullScrButtonId     : "calp-full-toggle",
      maxwidth            : 1200,
      frameHeight         : 600,
      zIndexFull          : 10001,
      zIndexNormal        : 1,
      cookieName          : "calp-full-screen",
    
      /*init: function() {
        var cookie = jQuery.cookie(this.cookieName);
        if ( cookie ) {
          this.toggle();
        }
      }, */ 
    
      toggle: function() {
        var toggleButton = jQuery('#'+this.fullScrButtonId);
        var toggle;
    
        var toggle = toggleButton.hasClass(this.offClass) ? true : false;
        var frame = jQuery('.'+this.mainFrame);
        var cover = jQuery('#'+this.cover);
    
        var setClass = jQuery('body').width() > this.maxwidth ? this.fullscreenBigClass : this.fullscreenClass;
        //var setCookie = toggle ? toggle : null;
    
        //jQuery.cookie(this.cookieName, setCookie, {expire: 7, path: '/'});
        
     if ( toggle ) {
          toggleButton.removeClass(this.offClass).addClass(this.onClass);
    
          frame.addClass(setClass);
          var wHeight = jQuery(window).height();
          var top = Math.floor((wHeight - frame.height())/2);
          frame.css('width',  jQuery(window).width() / 1.1 );
          frame.css('left',  (jQuery(window).width() - jQuery(window).width() / 1.1) / 2 );
          frame.css('position', 'fixed');
          frame.css('top', top);
          frame.css('z-index', this.zIndexFull);
          cover.show();
        } else {
          toggleButton.removeClass(this.onClass).addClass(this.offClass);
          frame.removeClass(this.fullscreenClass+" "+this.fullscreenBigClass);
          frame.css('position', '');
          frame.css('top', '');
          frame.css('left', '');
          frame.css('width',  '');
          frame.css('z-index', this.zIndexNormal);
          cover.hide();
        }
      }
    }
